@@ -1,4 +1,4 @@
-/*	$NetBSD: boot.c,v 1.33 2016/06/11 06:43:47 dholland Exp $	*/
+/*	$NetBSD: boot.c,v 1.34 2016/08/31 16:24:34 martin Exp $	*/
 
 /*
  * Copyright (c) 1997, 1999 Eduardo E. Horvath.  All rights reserved.
@@ -255,6 +255,7 @@ static void
 jump_to_kernel(u_long *marks, char *kernel, char *args, void *ofw,
 	int boothowto)
 {
+  printf("jump_to_kernel\n");
 	int l, machine_tag;
 	long newargs[4];
 	void *ssym, *esym;
@@ -363,9 +364,11 @@ static void
 start_kernel(char *kernel, char *bootline, void *ofw, int isfloppy,
 	int boothowto)
 {
+  printf("start_kernel\n");
 	int fd;
-	u_long marks[MARK_MAX];
+	u_long marks[MARK_MAX] = {0};
 	int flags = LOAD_ALL;
+
 	if (isfloppy)
 		flags &= ~LOAD_BACKWARDS;
 
