@@ -1,4 +1,4 @@
-/*	$NetBSD: loadfile_machdep.c,v 1.15 2016/08/15 08:29:34 maxv Exp $	*/
+/*	$NetBSD: loadfile_machdep.c,v 1.16 2016/11/04 20:04:11 macallan Exp $	*/
 
 /*-
  * Copyright (c) 2005 The NetBSD Foundation, Inc.
@@ -353,7 +353,8 @@ mmu_mapin_sun4u(vaddr_t rva, vsize_t len)
 					1,		/* cache */
 					1,		/* alias */
 					1,		/* valid */
-					0		/* endianness */
+					0,		/* endianness */
+					0		/* wc */
 					);
 			data |= SUN4U_TLB_L | SUN4U_TLB_CV; /* locked, virt.cache */
 
@@ -429,7 +430,8 @@ mmu_mapin_sun4v(vaddr_t rva, vsize_t len)
 			1,		/* cache */
 			1,		/* alias */
 			1,		/* valid */
-			0		/* endianness */
+			0,		/* endianness */
+			0		/* wc */
 			);
 		data |= SUN4V_TLB_CV; /* virt.cache */
 		
@@ -605,6 +607,7 @@ sparc64_memset(void *dst, int c, size_t size)
 void
 sparc64_finalize_tlb(u_long data_va)
 {
+printf("sparc64_finalize_tlb\n");
 #ifdef SUN4V
 	if ( sun4v )
 		sparc64_finalize_tlb_sun4v(data_va);
@@ -646,7 +649,8 @@ sparc64_finalize_tlb_sun4u(u_long data_va)
 				1,		/* cache */
 				1,		/* alias */
 				1,		/* valid */
-				0		/* endianness */
+				0,		/* endianness */
+				0		/* wc */
 				);
 		data |= SUN4U_TLB_L | SUN4U_TLB_CV; /* locked, virt.cache */
 		if (!writable_text)
@@ -668,12 +672,14 @@ sparc64_finalize_tlb_sun4u(u_long data_va)
 void
 sparc64_finalize_tlb_sun4v(u_long data_va)
 {
+  printf("sparc64_finalize_tlb_sun4v\n");
 	int i;
 	int64_t data;
 	bool writable_text = false;
 	int64_t hv_rc;
 
 	for (i = 0; i < dtlb_slot; i++) {
+	  printf("i = %d\n", i);
 		if (dtlb_store[i].te_va >= data_va) {
 			/*
 			 * If (for whatever reason) the start of the
@@ -696,31 +702,38 @@ sparc64_finalize_tlb_sun4v(u_long data_va)
 			1,		/* cache */
 			1,		/* alias */
 			1,		/* valid */
-			0		/* endianness */
+			0,		/* endianness */
+			0		/* wc */
 			);
 		data |= SUN4V_TLB_CV|SUN4V_TLB_X; /* virt.cache, executable */
 		if (!writable_text) {
+		  printf("before hv_mmu_unmap_perm_addr\n");
 			hv_rc = hv_mmu_unmap_perm_addr(dtlb_store[i].te_va,
 			                               MAP_DTLB);
 			if ( hv_rc != H_EOK ) {
 				panic("hv_mmu_unmap_perm_addr() failed - "
 				      "rc = %ld", hv_rc);
 			}
+		  printf("before hv_mmu_map_perm_addr\n");
 			hv_rc = hv_mmu_map_perm_addr(dtlb_store[i].te_va, data,
 			                             MAP_DTLB);
 			if ( hv_rc != H_EOK ) {
 				panic("hv_mmu_map_perm_addr() failed - "
 				      "rc = %ld", hv_rc);
 			}
+		  printf("after hv_mmu_map_perm_addr\n");
+			
 		}
 		
 		itlb_store[itlb_slot] = dtlb_store[i];
 		itlb_slot++;
+		printf("before 2 hv_mmu_map_perm_addr\n");
 		hv_rc = hv_mmu_map_perm_addr(dtlb_store[i].te_va, data,
 		                             MAP_ITLB);
 		if ( hv_rc != H_EOK ) {
 			panic("hv_mmu_map_perm_addr() failed - rc = %ld", hv_rc);
 		}
+		printf("after 2 hv_mmu_map_perm_addr\n");
 	}
 	if (writable_text)
 		printf("WARNING: kernel text mapped writable!\n");
