@@ -183,7 +183,7 @@ struct intrmap intrmap[] = {
 #define ACDB_BOOTDEV	0x1
 #define	ACDB_PROBE	0x2
 #define ACDB_BOOTARGS	0x4
-int autoconf_debug = 0x1;
+int autoconf_debug = 0xff;
 #define DPRINTF(l, s)   do { if (autoconf_debug & l) printf s; } while (0)
 #else
 #define DPRINTF(l, s)
