@@ -1048,13 +1048,14 @@ data_access_fault(struct trapframe64 *tf, unsigned int type, vaddr_t pc,
 	u_quad_t sticks;
 	ksiginfo_t ksi;
 
-		printf("%ld: data_access_fault(%p, %x, %p, %p, %lx, %lx) "
-			"nsaved=%d\n",
-			(long)(curproc?curproc->p_pid:-1), tf, type,
-			(void *)pc, (void *)addr, 
-			sfva, sfsr, (int)curpcb->pcb_nsaved);
-
 #ifdef DEBUG
+#if 1
+	printf("%ld: data_access_fault(%p, %x, %p, %p, %lx, %lx) "
+	       "nsaved=%d\n",
+	       (long)(curproc?curproc->p_pid:-1), tf, type,
+	       (void *)pc, (void *)addr, 
+	       sfva, sfsr, (int)curpcb->pcb_nsaved);
+#endif
 	if (tf->tf_pc == tf->tf_npc) {
 		printf("data_access_fault: tpc %lx == tnpc %lx\n", 
 		       (long)tf->tf_pc, (long)tf->tf_npc);
